#
# spec file for package nextcloud
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#
%if 0%{?suse_version}
%define apache_serverroot /srv/www/htdocs
%define apache_confdir /etc/apache2/conf.d
%define apache_docdir /usr/share/doc/packages
%define apache_user wwwrun
%define apache_group www
%else
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
%define apache_serverroot /var/www/html
%define apache_confdir /etc/httpd/conf.d
%define apache_user apache
%define apache_group apache
%define __jar_repack 0
%else
%define apache_serverroot /var/www
%define apache_confdir /etc/httpd/conf.d
%define apache_user www
%define apache_group www
%endif
%endif

%define oc_user 	%{apache_user}
%define oc_dir  	%{apache_serverroot}/%{name}
%define ocphp_bin	/usr/bin

%if 0%{?rhel} == 600 || 0%{?rhel_version} == 600 || 0%{?centos_version} == 600
%define statedir	/var/run
%else
%define statedir	/run
%endif

Name:           nextcloud
Version:        13.0.1
Release:        6.1
Summary:        File hosting service
License:        AGPL-3.0
Group:          Productivity/Networking/Web/Utilities
Url:            http://www.nextcloud.com
Source0:        https://download.nextcloud.com/server/releases/%{name}-%{version}.tar.bz2
Source1:        apache_secure_data
Source2:        README
Source3:        README.SELinux
Source4:        README.SUSE
Source5:        robots.txt
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%if 0%{?suse_version}
BuildRequires:  apache2 >= 2.4
%if 0%{?suse_version} > 1020
BuildRequires:  fdupes
%endif
BuildRequires:  unzip
%endif
#
Requires:       curl
Requires:       mysql
Requires:       php-gd
Requires:       php-json
Requires:       php-mbstring
Requires:       php-mysql
Requires:       php-posix
Requires:       php-zip
#
%if 0%{?fedora_version} || 0%{?rhel} || 0%{?rhel_version} || 0%{?centos_version}
Requires:       php < 7.3.0
Requires:       php >= 5.6.0
Requires:       php-process
Requires:       php-xml
#
Recommends:     sqlite
%endif
#
%if 0%{?suse_version}
Requires:       apache2
Requires:       mod_php_any < 7.3.0
Requires:       mod_php_any >= 5.6.0
Requires:       php-ctype
Requires:       php-curl
# SUSE does not include the fileinfo module in php-common.
Requires:       php-fileinfo
Requires:       php-iconv
Requires:       php-openssl
Requires:       php-pear
Requires:       php-xmlreader
Requires:       php-xmlwriter
Requires:       php-zlib
#
Recommends:     sqlite3
%endif
#
Recommends:     php-imagick 
Recommends:     php-sqlite

%description
Nextcloud is a suite of client-server software for creating file
hosting services and using them.

%prep
%setup -q -n %{name}
cp %{SOURCE2} .
cp %{SOURCE3} .
cp %{SOURCE4} .
cp %{SOURCE5} .
### Don't remove git files!! 
### git files should not be removed, otherwise nextcloud rise up integrity check failure in some situations.
###
## delete unneeded gitfiles 
#rm -r `find . -name ".gitignore" -or -name ".gitkeep" -or -name ".github"`
## remove entries in signature.json to prevent integrity check failure
#find . -iname signature.json \
#    -exec sed -i "/\/.gitignore\": ./d" "{}" \;  \
#    -exec sed -i "/\/.gitkeep\": ./d" "{}" \; \
#    -exec sed -i "/\/.github\": ./d" "{}" \;
#rm -f 3rdparty/symfony/debug/Resources/ext/*.{c,h}

%build

%install
# no server side java code contained, alarm is false
idir=$RPM_BUILD_ROOT/%{apache_serverroot}/%{name}
mkdir -p $idir
mkdir -p $idir/data
mkdir -p $idir/search
cp -aRf * $idir
cp -aRf .htaccess $idir
cp -aRf .user.ini $idir
# $idir/l10n to disappear in future
#rm -f $idir/l10n/l10n.pl

if [ ! -f $idir/robots.txt ]; then
  install -p -D -m 644 %{SOURCE5} $idir/robots.txt
fi

# create the AllowOverride directive
install -p -D -m 644 %{SOURCE1} $RPM_BUILD_ROOT/%{apache_confdir}/nextcloud.conf
ocpath="%{apache_serverroot}/%{name}"
sed -i -e"s|@DATAPATH@|${ocpath}|g" $RPM_BUILD_ROOT/%{apache_confdir}/nextcloud.conf

# not needed for distro packages
rm -f ${idir}/indie.json

%if 0%{?suse_version}
# link duplicate doc files
%fdupes -s $RPM_BUILD_ROOT/%{apache_serverroot}/%{name}
%endif

%pre
# avoid fatal php errors, while we are changing files
# https://github.com/nextcloud
#
# We don't do this for new installs. Only for updates.
# If the first argument to pre is 1, the RPM operation is an initial installation. If the argument is 2, 
# the operation is an upgrade from an existing version to a new one.
if [ $1 -gt 1 -a ! -s %{statedir}/apache_stopped_during_nextcloud_install ]; then	
  echo "%{name} update: Checking for running Apache"
  # FIXME: this above should make it idempotent -- a requirement with openSUSE.
  # it does not work.
%if 0%{?suse_version} && 0
%if 0%{?suse_version} <= 1110
  rcapache2 status       | grep running > %{statedir}/apache_stopped_during_nextcloud_install
  rcapache2 stop
%else
  service apache2 status | grep running > %{statedir}/apache_stopped_during_nextcloud_install
  service apache2 stop
%endif
%endif
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
  service httpd status | grep running > %{statedir}/apache_stopped_during_nextcloud_install
  service httpd stop
%endif
fi
if [ -s %{statedir}/apache_stopped_during_nextcloud_install ]; then
  echo "%{name} pre-install: Stopping Apache"
fi

if [ $1 -eq 1 ]; then
    echo "%{name}-server: First install starting"
else
    echo "%{name}-server: installing upgrade ..."
fi
# https://github.com/nextcloud
if [ -x %{ocphp_bin}/php -a -f %{oc_dir}/occ ]; then
  echo "%{name}: occ maintenance:mode --on"
  su %{oc_user} -s /bin/sh -c "cd %{oc_dir}; PATH=%{ocphp_bin}:$PATH php ./occ maintenance:mode --on" || true
  echo yes > %{statedir}/occ_maintenance_mode_during_nextcloud_install
fi

%post
if [ $1 -eq 1 ]; then
    echo "%{name} First install complete"
else
    echo "%{name} Upgrade complete"
fi

%if 0%{?suse_version}
# make sure php5 is not in APACHE_MODULES, so that we don't create dups.
perl -pani -e 's@^(APACHE_MODULES=".*)\bphp5\b@$1@' /etc/sysconfig/apache2
# add php5 to APACHE_MODULES
perl -pani -e 's@^(APACHE_MODULES=")@${1}php5 @' /etc/sysconfig/apache2
%endif

if [ -s %{statedir}/apache_stopped_during_nextcloud_install ]; then
  echo "%{name} post-install: Restarting Apache"
  ## If we stopped apache in pre section, we now should restart. -- but *ONLY* then!
  ## Maybe delegate that task to occ upgrade? They also need to handle this, somehow.
%if 0%{?suse_version}
%if 0%{?suse_version} <= 1310
  rcapache2 start
%else
  rcapache2 restart apache2.service
%endif
%endif
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
  service httpd start
%endif
fi

if [ -s %{statedir}/occ_maintenance_mode_during_nextcloud_install ]; then
echo "%{name}: occ upgrade"
su %{oc_user} -s /bin/sh -c "cd %{oc_dir}; PATH=%{ocphp_bin}:$PATH php ./occ upgrade" || true
echo "%{name}: occ maintenance:mode --off"
su %{oc_user} -s /bin/sh -c "cd %{oc_dir}; PATH=%{ocphp_bin}:$PATH php ./occ maintenance:mode --off" || true
fi

rm -f %{statedir}/apache_stopped_during_nextcloud_install
rm -f %{statedir}/occ_maintenance_mode_during_nextcloud_install

%files
%defattr(644,root,root,755)
%exclude %{apache_serverroot}/%{name}/README
%exclude %{apache_serverroot}/%{name}/README.SUSE
%exclude %{apache_serverroot}/%{name}/README.SELinux
%doc README README.SUSE README.SELinux
%{apache_serverroot}/%{name}
%attr(-,wwwrun,www) %{apache_serverroot}/%{name}/occ
%config(noreplace) %{apache_confdir}/nextcloud.conf
%config(noreplace) %{apache_serverroot}/%{name}/.user.ini
%defattr(664,wwwrun,www,775)
%{apache_serverroot}/%{name}/apps
%defattr(660,wwwrun,www,770)
%{apache_serverroot}/%{name}/config
%{apache_serverroot}/%{name}/data

%changelog
* Fri Apr 13 2018 ecsos@opensuse.org
- Nextcloud 11 is no more supported.
  Nextcloud Server before 11.0.7 have security issues.
- This fix CVE-2017-0936 and boo#1087402: package security issue
* Thu Mar 15 2018 ecsos@opensuse.org
- update to 13.0.1
  - Dont polute the log on DAV emaillogin (server#8045)
  - Don't perform CSRF check on OCS routes with Bearer auth
    (server#8099)
  - Use S3Client::upload instead of splitting single/multipart
    upload ourselves (server#8102)
  - Remove old perl script to update l10n files (server#8145)
  - Scss hardening (server#8156)
  - Do not try to get the jailed path if we can't find the id
    (server#8177)
  - Handle SSL certificate verifications for others than
    Let's Encrypt (server#8183)
  - Use a phan version instead of master (server#8195)
  - Repair step to clear frontend related caches (server#8197)
  - Keep previous exception when transforming to dav exception
    (server#8228)
  - Actually return stream from swift (server#8250)
  - Remove invalid link to documentation (server#8253)
  - Fix deleting folders when using s3 external storage
    (server#8261)
  - Link to NC13 dev manual (server#8264)
  - Better result handling of email search (server#8267)
  - Update CRL to revoke files_rightclick (server#8271)
  - Fix styling issues of guest pages #8155 (server#8286)
  - Remove jquery ui background image (server#8287)
  - Show open graph preview in WhatsApp (server#8309)
  - Make acceptance tests for comments more consistent with the
    others (server#8395)
  - Fix edit tag textbox size (server#8407)
  - Use TTF fonts for avatar generation (server#8440)
  - Use mb_* string methods to extract first character for
    generated avatars (server#8470)
  - Show hint in OCS API for user creation (server#8515)
  - Fix hiding and event propagation issues with the user
    management popover (server#8517)
  - Add some whitespace around change.svg icon (server#8518)
  - Avoid fruitless login attempts (server#8532)
  - Fix retrieval of group members with numerical uids from LDAP
    (server#8536)
  - Theming: handle not being in the serverroot (server#8554)
  - Ext storage error warning (server#8561)
  - Set autocomplete=new-password for mail share password
    (server#8577)
  - Fix upload button visible on read-only folders (server#8595)
  - Fixed app navigation for IE11 (server#8609)
  - Fix breadcrumbs width calculation (server#8610)
  - Fix comments (and systemtags) when involving users with
    numerical ids (server#8615)
  - Update commentstabview.js (server#8621)
  - Properly encapsulate require_once for app.php (server#8631)
  - AppData hardening (server#8636)
  - Use hash algo that's robust against collisions (server#8654)
  - Fixed date/time picker on IE11 (server#8663)
  - Use a more widely available method to test s3 settings
    (server#8667)
  - Use proper lanugage in langauge code (server#8668)
  - Display the proper language strings in setttings (server#8669)
  - Do not create empty userid when attribute does not have allowed
    chars (server#8673)
  - Remove too restrict check for background image/color
    (server#8675)
  - Fix example regex for user agent matching (server#8676)
  - Generate different UIDs for Birthday, Anniversary and Death
    event (server#8678)
  - Don't use double quotes in MySQL queries (server#8680)
  - Log exceptions that happen when writing the app store reply
    to storage (server#8683)
  - Set the correct active navigation entry (server#8685)
  - Fix activities for end2end encryption (server#8686)
  - Filter out the current user when searching for emails too
    (server#8687)
  - Fix check if theming defaults instance is available
    (server#8688)
  - Fix undefined index problem (server#8693)
  - Disable part files for object stores (server#8725)
  - Better handling of invisible elements in acceptance tests
    (server#8738)
  - Remove base url from global cache prefix (server#8745)
  - Check if the cached js file exists (server#8746)
  - Sharee email matches not limited (server#8749)
  - Fix integer overflow in ChunkingPlugin (server#8752)
  - Revert wording back to updates (server#8755)
  - Add acceptance tests for permissions on public shared folders
    (server#8758)
  - Also send file emails in ASAP mode (activity#249)
  - Ensure userids are strings (activity#252)
  - Null coalescing operator is PHP7+ (activity#254)
  - Update PDF.js to 1.9.426 (files_pdfviewer#55)
  - Enable full screen mode for PDF files (files_pdfviewer#59)
  - Fix ACE module files failing to load (files_texteditor#83)
  - Do not keep FileInfoModels returned by "getModelForFile"
    (files_texteditor#89)
  - Fix share drop down in gallery not properly shown (gallery#394)
  - Fix gallery button hidden in folders without create permission
    (gallery#402)
  - Fix controls position in gallery layout (gallery#405)
  - Removed old code already present thanks to the files app
    (gallery#406)
  - Create "file app" public share links if the slideshow is
    opened from ... (gallery#407)
  - Allow to check against haveibeenpwned.com password list
    (password_policy#61)
* Tue Feb  6 2018 ecsos@opensuse.org
- update to 13.0.0
  Over 1100 changes were merged in the server, with many hundreds
  more in existing or new apps. The main improvements include:
  * Collaboration features
  - Nextcloud Talk, a private videoconference software integrated
    with Nextcloud
  - real-time and asynchronous communication with push
    notifications, calls and chat web and mobile devices
  - Integration in business workflow with calendar invitations
    and calls directly from Nextcloud Files
  - Screen and note sharing with participant moderation
    capabilities
  - 100%% secure peer-to-peer, end-to-end encrypted calls,
    mediated by self-hosted server
  - auto-completion of user names in comments and notification
    to the mentioned user
  - support free/busy scheduling in native calendar applications
    like Thunderbird Lightning
  - show meeting invites in the calendar
  * End-to-End Encryption
  - can encrypt data on a per-folder level rather than
    all-or-nothing approach
  - does not require users to remember or exchange passwords
  - does not require re-uploading data upon sharing
  - features an optional off-line administrator recovery key
  - allows full audit logging
  - can be combined with our File Access Control feature so
    administrator can enforce aspects of End-to-end Encryption
  - protects from identity theft with our Cryptographic Identity
    Protection feature
    This feature is in Tech Preview for Nextcloud 13 and does not
    yet implement sharing.
  * User Interface
  - new way of selecting files
  - easy way to quickly copy or move to a location
  - High DPI support
  - admin menu integrated in one list
  - no limitation to file uploads via the web interface
  - user quota in the side bar
  - social sharing (Twitter, G+, Facebook, Diaspora) now features
    a preview
  - improved theming
  * Performance
  - decreased page load times with up to 50%% and faster search
  - 80%% faster LDAP and up to 10x faster external storage
  - Server-side Encryption performance largely improved
  See https://nextcloud.com/changelog/
* Wed Jan 24 2018 ecsos@opensuse.org
- update to 12.0.5
  Many fixes were merged, the most important ones include:
  - #7144 Unlock files even if an exception occurs
  - #7322 Set primary action button color to same as theming color
  - #7323 Use the correct root for shared jail when the source
    storage is also a jail
  - #7353 Fix translation of federation scope menu
  - #7362 Allow to skip data dir permission checks
  - #7407 Check if owner of share exists
  - #7409 Add retry wrapper when reading files from swift
  - #7451 Fix constructor spy in unit test with Sinon 4.1.3
  - #7455 Remove wrong entry in admin_settings that causes 500
  - #7456 CardDAV convertor check should not be to wide
  - #7457 Fix loading icon position in the app menu
  - #7464 Allow getting the filepath when getting cached mounts
  - #7468 Allow 'Nextcloud' in the user agent string of Android
  - #7558 Fix email buttons for white theme
  - #7567 Respect sharing options when searching for Sharees
  - #7568 Fix duplicate session token after remembered login
  - #7577 Check userExists later,
    saves lookups for appData_INSTANCEID userids
  - #7672 Added additional methods for removal of sensitive info
  - #7688 Fix scss webroot and url rewrite
  - #7717 Throw ServerNotAvailableException when LDAP is caught
    shutting down
  - #7666 Fix drag shadow not visible when dragging a file on
    a narrow screen
  - #7674 Do no run SyncJob in cron
  - #7684 Fix inverted app icons on IE11
  - #7694 Don't attempt to translate login names to uids when uids
    are provided
  - #7708 Don't show recurring msg when pages result was turned off
  - #7742 Hide favourite icon in details view if favourite action
    is not available
  - #7745 Don't lie about preview types
  - #7747 Update of composer
  - #7758 add option to use legacy v2 auth with s3
  - #7759 Use correct L10N files for jsconfig
  - #7757 Wait for the shared link to be set in the acceptance
    tests
  - gallery/#349 Fix date picker not visible in slideshow sharing
    dialog
  - activity/#229 Properly construct path of root on file rename
  - #7770 Fix SCSS processing when undoing theming values
  - #7774 Update icewind/smb to 2.0.3
  - #7777 Set height for sidebar icons
  - #7779 Improve zip support
  - #7786 Return correct mount type for federated shares
  - #7792 Fix empty details view after renaming a file
  - #7817 Fix preview when theming changes invertion of icons
  - #7821 Log full exception in cron instead of only the message
  - #7888 Keep all shipped apps enabled because they should be okay
  - #7962 update icewind/smb to 2.0.4
* Tue Dec 19 2017 ecsos@opensuse.org
- Nextcloud 12 is not compatible with php ≥ 7.2,
  so php < 7.2 is needed.
* Mon Dec  4 2017 ecsos@opensuse.org
- upstream update to version 12.0.4
  * Server
    Over 50 fixes were merged in the server.
  - Improve text: 'you have now' -> 'you now have (server#6464)
  - Fix initializing paged search under some circumstances
    (server#6502)
  - LDAP: simplify returning the homePath (server#6509)
  - Fix sharer name overlap with filename (server#6524)
  - Allow to close sidebar for text files (server#6525)
  - Fix quota new endpoint 12 (server#6527)
  - Pass new value to triggerChange (server#6528)
  - Throw 101 when an empty group string is provided
    (server#6547)
  - Contacts menu privacy (server#6554)
  - Add color-border variable (server#6649)
  - Do not stop on scss compilation failure (server#6661)
  - Don't pass User object when uid string is expected
    (server#6674)
  - Navigate to the root directory when showing the main filelist
    (server#6689)
  - Fix LDAP User deletion (cleanup) (server#6699)
  - Update aws sdk + s3 improvements (server#6737)
  - Dont run invalid path repair step when upgrading
    from 11.0.5.2 and later (server#6743)
  - Fix language when trying to change password (server#6751)
  - Fix postgresql tests (server#6792)
  - Also use configured 'cache_path' for new chunking
    (server#6814)
  - Set s3 part size to 500mb (server#6815)
  - Fix contacts menu for IE11 (server#6823)
  - Still trigger conflict resolution for existing entries when
    the curre (server#6847)
  - Propagate multipart upload exception when aborting upload
    (server#6855)
  - Allow to migrate from 10.0.3.3 (server#6878)
  - Timespan check (server#6896)
  - Do not log WebDAV maintenance mode exception (server#6908)
  - Don't reset quota (server#6910)
  - Backport of translation string fixes (server#6935)
  - Fix class name in exception logger plugin (server#6942)
  - Allow quota of 0 again (server#6943)
  - Fix uninitialized variable $this->params (server#6944)
  - Don't add a LIKE condition when it's not needed (server#6945)
  - Fix undefined offset warning when using '/' as external
    storage root (server#6946)
  - Fix page title not changed (server#6987)
  - Better readability for text on log in page which is directly
    on backgrounds (server#7028)
  - Translate Grant Access (server#7040)
  - Use fopen directly when reading objects from s3 (server#7079)
  - Improve mimetype detection for object storages (server#7081)
  - Fix seeking on object storage (server#7082)
  - Hide spinner for initial install (server#7095)
  - Ensure uid for calendar objects is unique (server#7096)
  - Revert "Only allow colons in db host for IPv6 addresses
    (server#7102)
  - Theme flow redirection page (server#7114)
  - Fix icon for security settings (server#7116)
  - If for some reason the json can't be decoded it is not cached
    (server#7118)
  - Improve performance of UserMountCache with external storage
    folders (server#7120)
  - {J,CS}SResourceLocator: account for symlinks in app path
    (server#7170)
  - Fix s3 download and touch (server#7186)
  - Touch opertation on object storage, don't create
    the file cache entry to early (server#7207)
  - Allow migration from upcoming 10.0.4 ownCloud release
    (server#7245)
  - CSSResourceLocator: handle SCSS in apps outside root
    (server#7257)
  - only replace permission popupmenu (server#7259)
  - Fix accesslist when a user has an ID only containting 0-9
    (server#7262)
  - Update CRL due to files_frommail (server#7277)
  - Only in case of $currentAccess the array uses the id as index
    (server#7328)
  * Other
  - Add aws sdk (3rdparty#69)
  - Don't send emails to disabled users (activity#202)
  - Add an option to disable emails completly (activity#206)
  - Make sure the mountPoint property is public before using it
    (files_accesscontrol#79)
  - Allow to playback m4v files (files_videoplayer#43)
  - Fix notifications order (notifications#93)
* Tue Sep 19 2017 ecsos@opensuse.org
- upstream update to version 12.0.3
  Nextcloud 12.0.3 delivers a lot of enhancements in various areas
  including:
  - A number of improvements to email notification templates
  - 2FA enhancements
  - Smarter LDAP password handling
  - File Drop and upload-in-general updates
  - A performance improvement handling large files
  See https://nextcloud.com/changelog/#latest12
  Details: https://github.com/nextcloud/server/pulls?q=is%%3Apr+milestone%%3A%%22Nextcloud+12.0.3%%22+is%%3Aclosed
* Tue Aug 15 2017 ecsos@opensuse.org
- upstream update to version 12.0.2
  * Server
  - Minor bugfix release
* Thu Aug 10 2017 ecsos@opensuse.org
- upstream update to version 12.0.1
  So many changes. See https://nextcloud.com/changelog/#latest12
* Mon Jul 17 2017 ecsos@opensuse.org
- unneeded git-files should not be remove,
  otherwise it throw integrity check failure in some situations.
* Mon May 22 2017 ecsos@opensuse.org
- upstream update to version 12.0.0
  no changelog from upstream at this time
  See https://github.com/nextcloud/server/issues?q=is%%3Aissue+milestone%%3A%%22Nextcloud+12.0%%22+is%%3Aclosed
* Fri Apr 28 2017 ecsos@opensuse.org
- fix boo#1036756: package security issue
* Mon Apr 24 2017 adamradovits12@hotmail.com
- upstream update to version 11.0.3
  * Server
  - Use the correct principal for shared addressbooks
  (server/3608)
  - Fix saving backup codes by using a correct data uri
  (server/3652)
  - Update icewind/streams to 0.5.2 (server/32931)
  - Fix string comparison and return docs (server/3665)
  - Typecast shared mount's storage_id to int as documented
    + some refactor to avoid similar bugs (server/3658)
  - Use a proper date format for transfer ownership
  (server/3700)
  - DAV sharing permissions should not depend on the order
  (server/3722)
  - Add new user agent of windows 10 dav backend
  (server/37641)
  - Add back appstoreenabled config switch (server/37671)
  - Call right function after sudo mode (server/3820)
  - Dont allow empty wildcard search (server/3842)
  - Remove single quotes around search query like in
  user search (server/3849)
  - Fix mimetype detection on public uploads for the
  workflow engine (server/3765)
  - Fix branding and show Nextcloud (server/39691)
  - Fix reshare with user activity message (server/39812)
  - Create correct VCard and return correct error codes
  (server/4029)
  - Prevent migration from ownCloud 10 to Nextcloud 11
  (server/34151)
  - Make sure transparency is an integer when saving a
  calendar (server/4167)
  - Make public links work with master key (server/42071)
  - Don't try to render the avatars if avatars are
  disabled (server/4214)
  - Reduce error message text (server/42281)
  - Don't list on public calendar endpoints (server/4229)
  - Fix upload of folders in Chrome (server/4154)
  - Make sure blob columns are correctly converted as
  parameters (server/4233)
  - Save the scope of an auth token in the session
  (server/4225)
  - Take share by mail into consideration if we calculate
  the access list (server/4242)
  - Also add the root of external storages to the file id
  list (server/4237)
  - Fix LDAP description (server/42382)
  - Remove the double password confirmation on changing
  cron (server/4236)
  - Fix scheduling plugin on legacy caldav endpoint
  (server/4235)
  - Directly fix invalid values of DTEND and DTSTART
  (server/4234)
  - Make JobList::next() lock free (server/4254)
  - Don't remove owner property for public calendars
  (server/4272)
  - Add capabilities for share by mail (server/42511)
  - Dont use the permissions mask while scanning
  (server/4278)
  - Add missing maintenance plugin to new DAV endpoint
  (server/4290)
  - Fix bug with shared_by for own calendars if shared
  (server/4301)
  - Translation string corrected > 1 user (server/4377)
  * Activity
  - Fix activities for "Files drop" on external storages
  (activity/118)
  * User_SAML
  - Bump to php-saml 2.10.5 (user_saml/1001)
  * Logreader
  - Small screen layout improvements
  (logreader/2bcd915969386ceb77c7f91dfd5fc19fd3212346
  - Fix log filtering
  (logreader/4095dfc62dcceb3c59a3f581baa5589737d0e6f3)
  - Greatly speedup log iteration
  (logreader/71a4c6849641f821e80d96674c57a69fe7a8aa9e)
  - Search more rows
  (logreader/b9d00b5599ac8a76862895266f1c23096391aad8)
  - Stop iterating if we dont have a valid file handle
  (logreader/a87a8e653ecae5efef6342e645b98f2878219c87)
  - Don't return a LogIterator on a broken handle
  (logreader/39069108f99d463b1cb8bc944f3ef24324b9f43d)
  - More robust log iteration
  (logreader/c0eb04d55bf1dee94ef523dae0e3b0e6afc272a6)
  - Use proper iso date format
  (logreader/13a31181a6d72d084797a71f49f2c5edee8c8dae)
  - Automatically try to fix some common escape errors from
  copy-pasted log entries
  (logreader/031db2a7f9b9f8cee42acf6eae7d993d31d4660a)
  - Fix stack trace parsing of incorrectly escaped logentries
  (logreader/538667770edfdd48374ef33e9c15498ed98ece60)
  - Highlight entries from the same request when clicking
  on an entry
  (logreader/2d1ccd0e4cca32220fcbe0b4d79d1cd23f0e73a5)
  - Fix copy paste info searchfield
  (logreader/0e91b2f46649a720feb7c3b6b8266b8657db5574)
  - Fix reset search after 0 results
  (logreader/50bec8ecf7edd81cfb96a35089283c0d879b41f3)
  - Allow searching for requestId and user
  (logreader/7f84e55bb4a1e4086ab0918a6bf58ad3885bbd91)
  - Allow searching in url
  (logreader/7833d97cf85fd351d2f7550d67d21bd0c2a815f4)
  - Fix infinite scroll
  (logreader/cbe874c6c068b9156ad8456edf31d112da40cbc9)
  - Dont show loading indicator if we already have entries
  (logreader/d26a08dc0540126177e8d20c3e243b44c5a399c4)
  * Gallery
  - Fix upload after core changes
  (gallery/b4ac4429841cfe2b7ea260dfb37fcde25580143c2)
  - Update JavaScript libraries (gallery/247)
* Thu Mar  2 2017 jengelh@inai.de
- Remove empty %%postun and redundant %%clean.
- Ensure summary/description is neutral.
* Tue Feb 28 2017 ecsos@opensuse.org
- upstream update to version 11.0.2
  * Server
  - Use login name to fix password confirm with ldap users
    (server/2953)
  - Change the row-format before changing the collation
    (server/3063)
  - Generate correct path for owner and use the display name
    (server/3080)
  - Markdown support for app descriptions (server/3117)
  - Fix style in comment (server/3143)
  - Escape the name for the jquery selector (server/3138)
  - Define spreed calls (server/3115)
  - LDAP Backend OCS Api (server/3213)
  - Fix Sharing app description (server/3397)
  - Fix shared-as-busy events for owner (server/3363)
  - Use correct theming when returning the defaults (server/3399)
  - Filter out sensitive appconfig values (server/3400)
  - Add transifex config for sharebymail (server/3423)
  - Update the email in the accounts table as well (server/3411)
  - Don't log the password on confirmPassword when LDAP throws an
    exception (server/3414)
  - Make sure ownCloud 8.2 activities also can get displayed
    (server/3412)
  - Popovermenu backport (server/3286)
  - Set vendor during install (server/3426)
  - Make sure the file information is available when sending the
    email (server/3433)
  - Add profile data to provisioning api (server/3259)
  - Fix detection of the new iOS app (server/3431)
  - Add integration tests for legacy DAV endpoints (server/3445)
  - Make sure invalid images don't flood the log file
    (server/3440)
  - Fix printing backup code (server/3510)
  - Fix cookie name (nctoken instead of octoken) (server/3511)
  - LDAP's checkPassword should only catch when a user was not
    found (server/3493)
  - Return unknown free space from nullstorage (server/3508)
  - Fix for address book data lost when any user receiving a
    share is deleted (server/3499)
  - Rename database password toggle (server/3500)
  - Popovermenu files css fix (server/3494)
  - Add screensharing icon (server/3481)
  - Fix misleading wording: searching is affected, not user
    access (server/3560)
  - Backport of Fix Broken UUID Attribute Detection (server/3528)
  * Activity
  - Make sure integer like names are still strings (activity/103)
  - Fix activities for public uploads (activity/113)
  - Show the parent as target when the file was not renamed
    (activity/114)
  - Fix activities for "Files drop" on external storages
    (activity/118)
  * SAML & SSO
  - Setup account later (user_saml/79)
  * Serverinfo
  - Fix SQL syntax error on MariaDB 10.0.27 and 10.1.19
    (serverinfo/77)
  - Don't throw an error when /proc/meminfo is not readable
    (serverinfo/76)
  * Survey_Client
  - Fix problem when checking size with dash in DB name
    (survey_client/50)
* Fri Jan 27 2017 guoyunhebrave@gmail.com
- Add php-openssl dependency
* Mon Jan 23 2017 ecsos@opensuse.org
- upstream update to version 11.0.1
* Wed Dec 14 2016 ecsos@opensuse.org
- upstream update to version 11.0.0
* Fri Sep 30 2016 ecsos@opensuse.org
- upstream update to version 10.0.1
* Sat Aug 27 2016 ecsos@opensuse.org
- upstream update to version 10.0.0
* Sun Aug  7 2016 chris@computersalat.de
- update spec file
  * osc service localrun format_spec_file
  * update Source with full URL
  * simplify deps mainly for openSUSE
* Sat Jul 23 2016 ecsos@opensuse.org
- enable HSTS to prevent the warning "The Strict-Transport-Security
  HTTP header is not configured" in admin-page
- turn maintenance:mode off after upgrade
* Thu Jul 21 2016 asemen@suse.de
- upstream update to version 9.0.53 (bsc#989998)
* Fri Jul  8 2016 ecsos@opensuse.org
- make apache_secure_data more restrictiver
- add missing .user.ini
- move README and README.SELinux to docdor to fix message code
  integrity check
* Tue Jul  5 2016 asemen@suse.de
- upstream update to version 9.0.52
* Fri Jul  1 2016 asemen@suse.de
- initial build nextcloud 9.0.51
